@@ -10,7 +10,7 @@ if ENV['COVERAGE'] == 'yes'
 
   SimpleCov.formatters = [
     SimpleCov::Formatter::HTMLFormatter,
-    SimpleCov::Formatter::Console
+    SimpleCov::Formatter::Console,
   ]
 
   SimpleCov.start do
