@@ -31,7 +31,7 @@ describe 'rake check:symlinks', type: :task do
     let(:test_files) do
       [
         File.join(Dir.pwd, 'files', 'a_file.pp'),
-        File.join(Dir.pwd, 'files', 'another_file.pp')
+        File.join(Dir.pwd, 'files', 'another_file.pp'),
       ]
     end
 
@@ -43,13 +43,13 @@ describe 'rake check:symlinks', type: :task do
   context 'when there is a symlink present' do
     let(:test_files) do
       [
-        File.join(Dir.pwd, 'files', 'a_file.pp')
+        File.join(Dir.pwd, 'files', 'a_file.pp'),
       ]
     end
 
     let(:symlinks) do
       {
-        File.join(Dir.pwd, 'files', 'a_symlink.pp') => File.join(Dir.pwd, 'files', 'a_file.pp')
+        File.join(Dir.pwd, 'files', 'a_symlink.pp') => File.join(Dir.pwd, 'files', 'a_file.pp'),
       }
     end
 
@@ -63,13 +63,13 @@ describe 'rake check:symlinks', type: :task do
   context 'when there are symlinks under .git/' do
     let(:test_files) do
       [
-        File.join(Dir.pwd, 'files', 'a_file.pp')
+        File.join(Dir.pwd, 'files', 'a_file.pp'),
       ]
     end
 
     let(:symlinks) do
       {
-        File.join(Dir.pwd, '.git', 'a_symlink.pp') => File.join(Dir.pwd, 'files', 'a_file.pp')
+        File.join(Dir.pwd, '.git', 'a_symlink.pp') => File.join(Dir.pwd, 'files', 'a_file.pp'),
       }
     end
 
@@ -81,13 +81,13 @@ describe 'rake check:symlinks', type: :task do
   context 'when there are symlinks under .bundle/' do
     let(:test_files) do
       [
-        File.join(Dir.pwd, 'files', 'a_file.pp')
+        File.join(Dir.pwd, 'files', 'a_file.pp'),
       ]
     end
 
     let(:symlinks) do
       {
-        File.join(Dir.pwd, '.bundle', 'a_symlink.pp') => File.join(Dir.pwd, 'files', 'a_file.pp')
+        File.join(Dir.pwd, '.bundle', 'a_symlink.pp') => File.join(Dir.pwd, 'files', 'a_file.pp'),
       }
     end
 
@@ -99,13 +99,13 @@ describe 'rake check:symlinks', type: :task do
   context 'when there are symlinks under vendor/' do
     let(:test_files) do
       [
-        File.join(Dir.pwd, 'files', 'a_file.pp')
+        File.join(Dir.pwd, 'files', 'a_file.pp'),
       ]
     end
 
     let(:symlinks) do
       {
-        File.join(Dir.pwd, 'vendor', 'a_symlink.pp') => File.join(Dir.pwd, 'files', 'a_file.pp')
+        File.join(Dir.pwd, 'vendor', 'a_symlink.pp') => File.join(Dir.pwd, 'files', 'a_file.pp'),
       }
     end
 
@@ -121,13 +121,13 @@ describe 'rake check:symlinks', type: :task do
 
     let(:test_files) do
       [
-        File.join(Dir.pwd, 'files', 'a_file.pp')
+        File.join(Dir.pwd, 'files', 'a_file.pp'),
       ]
     end
 
     let(:symlinks) do
       {
-        File.join(Dir.pwd, 'a_directory', 'a_symlink.pp') => File.join(Dir.pwd, 'files', 'a_file.pp')
+        File.join(Dir.pwd, 'a_directory', 'a_symlink.pp') => File.join(Dir.pwd, 'files', 'a_file.pp'),
       }
     end
 
@@ -145,13 +145,13 @@ describe 'rake check:symlinks', type: :task do
 
     let(:test_files) do
       [
-        File.join(Dir.pwd, 'files', 'a_file.pp')
+        File.join(Dir.pwd, 'files', 'a_file.pp'),
       ]
     end
 
     let(:symlinks) do
       {
-        File.join(Dir.pwd, 'another_directory', 'a_symlink.pp') => File.join(Dir.pwd, 'files', 'a_file.pp')
+        File.join(Dir.pwd, 'another_directory', 'a_symlink.pp') => File.join(Dir.pwd, 'files', 'a_file.pp'),
       }
     end
 
